slot_machine_effect library

Classes

SlotMachineReel
A single spinning reel, like a slot machine cylinder, that loops through its items and spins to a new value whenever SlotMachineReelController.spin is called.
SlotMachineReelController
Drives a SlotMachineReel imperatively: spins happen only when spin is called, never as a side effect of some other value changing.

Typedefs

SlotMachineItemBuilder = Widget Function(int value)
Builds the widget shown for a given reel value.